<?php
require_once 'config.php';
require_once 'vendor/autoload.php';

use Endroid\QrCode\QrCode;
use Endroid\QrCode\Writer\PngWriter;
use Endroid\QrCode\Color\Color;
use Endroid\QrCode\Logo\Logo;

$pageTitle = 'Bulk QR Code Generation';

// Fetch all categories
$stmt = $pdo->query("SELECT id, name FROM categories ORDER BY name");
$categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Fetch all products
$stmt = $pdo->query("SELECT id, name, sku, category_id FROM products ORDER BY name");
$products = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Handle AJAX request
if (isset($_GET['ajax']) && $_GET['ajax'] == 1) {
    $selected_products = $_POST['product_ids'] ?? [];
    $selected_category = $_POST['category_id'] ?? '';
    $select_all = isset($_POST['select_all']);
    $qr_size = intval($_POST['qr_size'] ?? 200);
    $qr_color = $_POST['qr_color'] ?? '#000000';

    // Handle logo upload
    $logo_path = null;
    if (isset($_FILES['qr_logo']) && $_FILES['qr_logo']['error'] == 0) {
        $allowed = array('jpg', 'jpeg', 'png', 'gif');
        $filename = $_FILES['qr_logo']['name'];
        $ext = pathinfo($filename, PATHINFO_EXTENSION);
        if (in_array(strtolower($ext), $allowed)) {
            $logo_path = 'uploads/logos/' . uniqid() . '.' . $ext;
            move_uploaded_file($_FILES['qr_logo']['tmp_name'], $logo_path);
        }
    }

    if ($select_all) {
        $selected_products = array_column($products, 'id');
    } elseif ($selected_category) {
        $selected_products = array_column(
            array_filter($products, function($p) use ($selected_category) {
                return $p['category_id'] == $selected_category;
            }),
            'id'
        );
    }

    $qr_codes = [];
    foreach ($selected_products as $product_id) {
        $stmt = $pdo->prepare("SELECT name, sku FROM products WHERE id = ?");
        $stmt->execute([$product_id]);
        $product = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($product) {
            $url = "http://" . $_SERVER['HTTP_HOST'] . dirname($_SERVER['PHP_SELF']) . "/public_product_view.php?id=" . $product_id;
            
            // Convert hex color to RGB
            list($r, $g, $b) = sscanf($qr_color, "#%02x%02x%02x");
            
            $qr = QrCode::create($url)
                ->setSize($qr_size)
                ->setMargin(10)
                ->setForegroundColor(new Color($r, $g, $b));
            
            $writer = new PngWriter();

            // Add logo if uploaded
            $logo = null;
            if ($logo_path) {
                $logo = Logo::create($logo_path)
                    ->setResizeToWidth($qr_size / 4);
            }

            $result = $writer->write($qr, $logo);

            $qr_codes[] = [
                'name' => $product['name'],
                'sku' => $product['sku'],
                'qr_code' => $result->getDataUri()
            ];
        }
    }

    // Delete temporary logo file
    if ($logo_path) {
        unlink($logo_path);
    }

    header('Content-Type: application/json');
    echo json_encode($qr_codes);
    exit;
}

ob_start();
?>

<div class="bg-white p-6 rounded-lg shadow-md">
    <h3 class="text-lg font-semibold text-gray-700 mb-4">Bulk QR Code Generation</h3>
    
    <form id="qr-form" action="" method="POST" enctype="multipart/form-data">
        <div class="mb-6">
            <label class="block text-gray-700 text-sm font-bold mb-2">Select Category:</label>
            <select name="category_id" class="form-select mt-1 block w-full rounded-md border-gray-300 shadow-sm">
                <option value="">Select a category</option>
                <?php foreach ($categories as $category): ?>
                    <option value="<?php echo $category['id']; ?>"><?php echo htmlspecialchars($category['name']); ?></option>
                <?php endforeach; ?>
            </select>
        </div>
        
        <div class="mb-6">
            <label class="block text-gray-700 text-sm font-bold mb-2">
                <input type="checkbox" id="select_all" name="select_all" value="1" class="mr-2">
                Select All Products
            </label>
        </div>
        
        <div class="mb-6">
            <label class="block text-gray-700 text-sm font-bold mb-2">Or Select Individual Products:</label>
            <div class="max-h-60 overflow-y-auto border border-gray-300 rounded-md p-2">
                <?php foreach ($products as $product): ?>
                    <div class="mb-1">
                        <label class="inline-flex items-center">
                            <input type="checkbox" class="form-checkbox" name="product_ids[]" value="<?php echo $product['id']; ?>">
                            <span class="ml-2"><?php echo htmlspecialchars($product['name'] . ' (' . $product['sku'] . ')'); ?></span>
                        </label>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        
        <div class="mb-6">
            <label class="block text-gray-700 text-sm font-bold mb-2">QR Code Size (px):</label>
            <input type="number" name="qr_size" value="200" min="100" max="1000" class="form-input mt-1 block w-full rounded-md border-gray-300 shadow-sm">
        </div>
        
        <div class="mb-6">
            <label class="block text-gray-700 text-sm font-bold mb-2">QR Code Color:</label>
            <input type="color" name="qr_color" value="#000000" class="form-input mt-1 block rounded-md border-gray-300 shadow-sm">
        </div>
        
        <div class="mb-6">
            <label class="block text-gray-700 text-sm font-bold mb-2">Logo (optional):</label>
            <input type="file" name="qr_logo" accept="image/*" class="form-input mt-1 block w-full rounded-md border-gray-300 shadow-sm">
            <p class="text-sm text-gray-600 mt-1">Upload a logo to be placed in the center of the QR code.</p>
        </div>
        
        <div class="flex items-center justify-between">
            <button type="submit" class="bg-orange-500 hover:bg-orange-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
                Generate QR Codes
            </button>
        </div>
    </form>

    <div id="qr-codes-container" class="mt-8 grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-6"></div>
</div>

<style>
@media print {
    body * {
        visibility: hidden;
    }
    #qr-codes-container, #qr-codes-container * {
        visibility: visible;
    }
    #qr-codes-container {
        position: absolute;
        left: 0;
        top: 0;
    }
    .no-print {
        display: none !important;
    }
}
</style>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script>
$(document).ready(function() {
    $('#select_all').change(function() {
        $('input[name="product_ids[]"]').prop('checked', this.checked);
    });

    $('#qr-form').submit(function(e) {
        e.preventDefault();
        var formData = new FormData(this);

        $.ajax({
            url: 'bulk_qr_generate.php?ajax=1',
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            dataType: 'json',
            success: function(response) {
                var container = $('#qr-codes-container');
                container.empty();

                response.forEach(function(item) {
                    var qrDiv = $('<div class="bg-white p-4 rounded-lg shadow-md text-center">');
                    qrDiv.append('<img src="' + item.qr_code + '" class="mx-auto mb-2" alt="QR Code">');
                    qrDiv.append('<p class="font-semibold">' + item.name + '</p>');
                    qrDiv.append('<p class="text-sm text-gray-600">' + item.sku + '</p>');
                    container.append(qrDiv);
                });

                // Add print button
                var printButton = $('<button class="mt-4 bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded no-print">Print QR Codes</button>');
                printButton.click(function() {
                    window.print();
                });
                container.prepend(printButton);
            },
            error: function() {
                alert('An error occurred while generating QR codes.');
            }
        });
    });
});
</script>

<?php
$pageContent = ob_get_clean();
require_once 'template.php';
?>